<?php
/**
 * A class holding general data about the application and some methods for
 * the management including the entry point.
 *
 * E.g.:
 *
 * index.php?app=my_app
 *
 * You need to create a folder in the folder "application" named "my_app"
 * (without the quotes) and create a include file called
 * class_ApplicationHelper.php. You have to write the same class for your
 * application and implement the same interface called ManageableApplication
 * because this class include file will be searched for.
 *
 * It is good when you avoid more GET parameters to keep URLs short and sweet.
 * But sometimes you need some GET paramerers e.g. for your imprint or info page
 * or other linked pages which you have to create and state some informations.
 *
 * Please remember that this include file is being loaded *before* the class
 * loader is loading classes from "exceptions", "interfaces" and "main"!
 *
 * @author		Roland Haeder <webmaster@mxchange.org>
 * @version		0.3.0
 * @copyright	Copyright(c) 2007, 2008 Roland Haeder, this is free software
 * @license		GNU GPL 3.0 or any newer version
 * @link 		http://www.mxchange.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
class ApplicationHelper extends BaseFrameworkSystem implements ManageableApplication {
	/**
	 * The version number of this application
	 */
	private $appVersion = "";

	/**
	 * The human-readable name for this application
	 */
	private $appName = "";

	/**
	 * The short uni*-like name of this application
	 */
	private $shortName = "";

	/**
	 * An instance of this class
	 */
	private static $thisInstance = null;

	/**
	 * Private constructor
	 *
	 * @return	void
	 */
	private function __construct () {
		// Call parent constructor
		parent::constructor(__CLASS__);

		// Set description
		$this->setObjectDescription("Application-Helper");

		// Create an unique ID
		$this->createUniqueID();

		// Tidy up a little
		$this->removeSystemArray();
	}

	/**
	 * Getter for an instance of this class
	 *
	 * @return	$thisInstance		An instance of this class
	 */
	public final static function getInstance () {
		// Is the instance there?
		if (is_null(self::$thisInstance)) {
			self::$thisInstance = new ApplicationHelper();
		}

		// Return the instance
		return self::$thisInstance;
	}

	/**
	 * Getter for the version number
	 *
	 * @return	$appVersion	The application's version number
	 */
	public final function getAppVersion () {
		return $this->appVersion;
	}

	/**
	 * Setter for the version number
	 *
	 * @param		$appVersion	The application's version number
	 * @return	void
	 */
	public final function setAppVersion ($appVersion) {
		// Cast and set it
		$appVersion = (string) $appVersion;
		$this->appVersion = $appVersion;
	}

	/**
	 * Getter for human-readable name
	 *
	 * @return	$appName	The application's human-readable name
	 */
	public final function getAppName () {
		return $this->appName;
	}

	/**
	 * Setter for human-readable name
	 *
	 * @param		$appName	The application's human-readable name
	 * @return	void
	 */
	public final function setAppName ($appName) {
		// Cast and set it
		$appName = (string) $appName;
		$this->appName = $appName;
	}

	/**
	 * Getter for short uni*-like name
	 *
	 * @return	$shortName	The application's short uni*-like name
	 */
	public final function getAppShortName () {
		return $this->shortName;
	}

	/**
	 * Setter for short uni*-like name
	 *
	 * @param		$shortName	The application's short uni*-like name
	 * @return	void
	 */
	public final function setAppShortName ($shortName) {
		// Cast and set it
		$shortName = (string) $shortName;
		$this->shortName = $shortName;
	}

	/**
	 * Launcher for the mxchange mailexchange script
	 *
	 * @return	void
	 */
	public final function entryPoint () {
		// Not yet implemented
		trigger_error(__METHOD__.": Not yet implemented!");
	}
}

// [EOF]
?>
